# Changelog

This is an auto-generated log of all the changes that have been made to the
project since release 0.7.0.

For the original changelog, please refer to the "OLD_CHANGELOG.md" file in the repository.

This project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).


## [0.13.0](https://github.com/seapagan/lice2/releases/tag/0.13.0) (November 13, 2024)

**New Features**

- Migrate from poetry to uv for dependency and project management ([#72](https://github.com/seapagan/lice2/pull/72)) by [seapagan](https://github.com/seapagan)

**Dependency Updates**

- Bump ruff from 0.6.3 to 0.6.4 ([#47](https://github.com/seapagan/lice2/pull/47)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump pymarkdownlnt from 0.9.22 to 0.9.23 ([#46](https://github.com/seapagan/lice2/pull/46)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump cryptography from 43.0.0 to 43.0.1 ([#43](https://github.com/seapagan/lice2/pull/43)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mkdocs-autorefs from 1.1.0 to 1.2.0 ([#42](https://github.com/seapagan/lice2/pull/42)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump ruff from 0.6.2 to 0.6.3 ([#41](https://github.com/seapagan/lice2/pull/41)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mkdocs-material from 9.5.33 to 9.5.34 ([#40](https://github.com/seapagan/lice2/pull/40)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mkdocs from 1.6.0 to 1.6.1 ([#39](https://github.com/seapagan/lice2/pull/39)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump poethepoet from 0.27.0 to 0.28.0 ([#38](https://github.com/seapagan/lice2/pull/38)) by [dependabot[bot]](https://github.com/apps/dependabot)

[`Full Changelog`](https://github.com/seapagan/lice2/compare/0.12.0...0.13.0) | [`Diff`](https://github.com/seapagan/lice2/compare/0.12.0...0.13.0.diff) | [`Patch`](https://github.com/seapagan/lice2/compare/0.12.0...0.13.0.patch)

## [0.12.0](https://github.com/seapagan/lice2/releases/tag/0.12.0) (September 02, 2024)

**New Features**

- Add some more licenses in common usage ([#34](https://github.com/seapagan/lice2/pull/34)) by [seapagan](https://github.com/seapagan)
- Add more language options ([#33](https://github.com/seapagan/lice2/pull/33)) by [seapagan](https://github.com/seapagan)
- Add an API so that lice can be used inside other applications ([#31](https://github.com/seapagan/lice2/pull/31)) by [seapagan](https://github.com/seapagan)
- Provide an optional JSON output, listing licenses and languages for easier integration into other tools like a GUI ([#30](https://github.com/seapagan/lice2/pull/30)) by [seapagan](https://github.com/seapagan)
- Add '--version' flag to the CLI ([#29](https://github.com/seapagan/lice2/pull/29)) by [seapagan](https://github.com/seapagan)

**Testing**

- Tweak some of the test layouts and contents ([#32](https://github.com/seapagan/lice2/pull/32)) by [seapagan](https://github.com/seapagan)

**Refactoring**

- Refactor some of the logic in the CLI ([#35](https://github.com/seapagan/lice2/pull/35)) by [seapagan](https://github.com/seapagan)

[`Full Changelog`](https://github.com/seapagan/lice2/compare/0.11.0...0.12.0) | [`Diff`](https://github.com/seapagan/lice2/compare/0.11.0...0.12.0.diff) | [`Patch`](https://github.com/seapagan/lice2/compare/0.11.0...0.12.0.patch)

## [0.11.0](https://github.com/seapagan/lice2/releases/tag/0.11.0) (August 28, 2024)

**New Features**

- Add option to copy directly to clipboard ([#27](https://github.com/seapagan/lice2/pull/27)) by [seapagan](https://github.com/seapagan)

**Dependency Updates**

- Bump rich from 13.7.1 to 13.8.0 ([#26](https://github.com/seapagan/lice2/pull/26)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump ruff from 0.6.1 to 0.6.2 ([#25](https://github.com/seapagan/lice2/pull/25)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mypy from 1.11.1 to 1.11.2 ([#24](https://github.com/seapagan/lice2/pull/24)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump mkdocs-autorefs from 1.0.1 to 1.1.0 ([#23](https://github.com/seapagan/lice2/pull/23)) by [dependabot[bot]](https://github.com/apps/dependabot)
- Bump typer from 0.12.4 to 0.12.5 ([#22](https://github.com/seapagan/lice2/pull/22)) by [dependabot[bot]](https://github.com/apps/dependabot)

[`Full Changelog`](https://github.com/seapagan/lice2/compare/0.10.2...0.11.0) | [`Diff`](https://github.com/seapagan/lice2/compare/0.10.2...0.11.0.diff) | [`Patch`](https://github.com/seapagan/lice2/compare/0.10.2...0.11.0.patch)

## [0.10.2](https://github.com/seapagan/lice2/releases/tag/0.10.2) (August 26, 2024)

**Closed Issues**

- Formatting issue with 'c', 'java' style and languages using the same comment template ([#17](https://github.com/seapagan/lice2/issues/17)) by [seapagan](https://github.com/seapagan)

**New Features**

- Add markdown mapping (same as HTML) ([#19](https://github.com/seapagan/lice2/pull/19)) by [seapagan](https://github.com/seapagan)

**Bug Fixes**

- Fix bug "formatting issue with 'c', 'java' style" ([#18](https://github.com/seapagan/lice2/pull/18)) by [seapagan](https://github.com/seapagan)

[`Full Changelog`](https://github.com/seapagan/lice2/compare/0.10.1...0.10.2) | [`Diff`](https://github.com/seapagan/lice2/compare/0.10.1...0.10.2.diff) | [`Patch`](https://github.com/seapagan/lice2/compare/0.10.1...0.10.2.patch)

## [0.10.1](https://github.com/seapagan/lice2/releases/tag/0.10.1) (August 26, 2024)

Purely a documentation fix so that the updated README gets to PyPI

[`Full Changelog`](https://github.com/seapagan/lice2/compare/0.10.0...0.10.1) | [`Diff`](https://github.com/seapagan/lice2/compare/0.10.0...0.10.1.diff) | [`Patch`](https://github.com/seapagan/lice2/compare/0.10.0...0.10.1.patch)

## [0.10.0](https://github.com/seapagan/lice2/releases/tag/0.10.0) (August 26, 2024)

**Bug Fixes**

- Fix extra spaces and CR in output ([#14](https://github.com/seapagan/lice2/pull/14)) by [seapagan](https://github.com/seapagan)

[`Full Changelog`](https://github.com/seapagan/lice2/compare/0.9.0...0.10.0) | [`Diff`](https://github.com/seapagan/lice2/compare/0.9.0...0.10.0.diff) | [`Patch`](https://github.com/seapagan/lice2/compare/0.9.0...0.10.0.patch)

## [0.9.0](https://github.com/seapagan/lice2/releases/tag/0.9.0) (August 24, 2024)

**New Features**

- Convert CLI from 'argparse' to 'typer' ([#8](https://github.com/seapagan/lice2/pull/8)) by [seapagan](https://github.com/seapagan)
- Add config file functionality ([#7](https://github.com/seapagan/lice2/pull/7)) by [seapagan](https://github.com/seapagan)

**Testing**

- Improve test coverage ([#9](https://github.com/seapagan/lice2/pull/9)) by [seapagan](https://github.com/seapagan)

**Documentation**

- Create a docs website for the project ([#11](https://github.com/seapagan/lice2/pull/11)) by [seapagan](https://github.com/seapagan)

[`Full Changelog`](https://github.com/seapagan/lice2/compare/0.8.0...0.9.0) | [`Diff`](https://github.com/seapagan/lice2/compare/0.8.0...0.9.0.diff) | [`Patch`](https://github.com/seapagan/lice2/compare/0.8.0...0.9.0.patch)

## [0.8.0](https://github.com/seapagan/lice2/releases/tag/0.8.0) (August 19, 2024)

**New Features**

- Add prettier output for the listing of licenses and languages ([#4](https://github.com/seapagan/lice2/pull/4)) by [seapagan](https://github.com/seapagan)

**Refactoring**

- Major refactor into separate files ([#5](https://github.com/seapagan/lice2/pull/5)) by [seapagan](https://github.com/seapagan)
- Move templates into subfolder ([#3](https://github.com/seapagan/lice2/pull/3)) by [seapagan](https://github.com/seapagan)
- Refactor with strict ruff and mypy linting ([#1](https://github.com/seapagan/lice2/pull/1)) by [seapagan](https://github.com/seapagan)

**Documentation**

- Add new CHANGELOG and consolidate the old ones ([#6](https://github.com/seapagan/lice2/pull/6)) by [seapagan](https://github.com/seapagan)

**Dependency Updates**

- Bump pre-commit from 3.5.0 to 3.8.0 ([#2](https://github.com/seapagan/lice2/pull/2)) by [dependabot[bot]](https://github.com/apps/dependabot)

[`Full Changelog`](https://github.com/seapagan/lice2/compare/0.7.0...0.8.0) | [`Diff`](https://github.com/seapagan/lice2/compare/0.7.0...0.8.0.diff) | [`Patch`](https://github.com/seapagan/lice2/compare/0.7.0...0.8.0.patch)

## [0.7.0](https://github.com/seapagan/lice2/releases/tag/0.7.0) (August 18, 2024)

This is the first release of this new fork. Main thing was getting the Python 3.12 compatibility fixed.

---
*This changelog was generated using [github-changelog-md](http://changelog.seapagan.net/) by [Seapagan](https://github.com/seapagan)*
